import { useTranslation } from "next-i18next";

import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
import useWidgetAPI from "utils/proxy/use-widget-api";
import classNames from "classnames";

export default function Component({ service }) {
  const { t } = useTranslation();
  const { widget } = service;
  const { data, error } = useWidgetAPI(widget, "widget", {
    refreshInterval: 2000,
  });

  if (error) {
    return <Container service={service} error={error} />;
  }

  if (!data) {
    return (
      <Container service={service} className={classNames(
                "bg-theme-200/50 dark:bg-theme-900/20 rounded m-1 flex-1 flex flex-col items-center justify-center text-center",
                "service-block",)}>
        <Block label="Now Playing" value="N/A - N/A" style={{ fontSize: "0.3em" }} />
        <Block label="Album" value="N/A" style={{ fontSize: "0.3em" }} />
        <Block label="Genre" value="N/A" style={{ fontSize: "0.3em" }} />
      </Container>
    );
  }

  return (
    <Container service={service} className={classNames(
              "bg-theme-200/50 dark:bg-theme-900/20 rounded m-1 flex-1 flex flex-col items-center justify-center text-center",
              "service-block",)}>
      <img src={`https://api.codey.lol/radio/album_art?${Date.now()}`} height={85} width={85}></img>
      <Block label="Now Playing" value={ data.now_playing } style={{ fontSize: "0.3em" }} />
      <Block label="Album" value= { data.album } style={{ fontSize: "0.3em" }} />
      <Block label="Genre" value={ data.genre } style={{ fontSize: "0.3em" }} />
    </Container>
  );
}

